@@ -333,7 +333,6 @@ static void parse_list(struct parser *p, int *indent, int num) {
 	}
 	list_header(p, &num);
 	parse_text(p);
-	bool closed = false;
 	do {
 		parse_indent(p, indent, true);
 		if ((ch = parser_getch(p)) == UTF8_INVALID) {
@@ -351,12 +350,9 @@ static void parse_list(struct parser *p, int *indent, int num) {
 			if ((ch = parser_getch(p)) != ' ') {
 				parser_fatal(p, "Expected space before start of list entry");
 			}
-			if (!closed) {
-				roff_macro(p, "RE", NULL);
-			}
+			roff_macro(p, "RE", NULL);
 			list_header(p, &num);
 			parse_text(p);
-			closed = false;
 			break;
 		default:
 			fprintf(p->output, "\n");
@@ -365,9 +361,7 @@ static void parse_list(struct parser *p, int *indent, int num) {
 		}
 	} while (ch != UTF8_INVALID);
 ret:
-	if (!closed) {
-		roff_macro(p, "RE", NULL);
-	}
+	roff_macro(p, "RE", NULL);
 }
 
 static void parse_literal(struct parser *p, int *indent) {
@@ -380,15 +374,19 @@ static void parse_literal(struct parser *p, int *indent) {
 	int stops = 0;
 	roff_macro(p, "nf", NULL);
 	fprintf(p->output, ".RS 4\n");
+	bool check_indent = true;
 	do {
-		int _indent = *indent;
-		parse_indent(p, &_indent, false);
-		if (_indent < *indent) {
-			parser_fatal(p, "Cannot deindent in literal block");
-		}
-		while (_indent > *indent) {
-			--_indent;
-			fprintf(p->output, "\t");
+		if (check_indent) {
+			int _indent = *indent;
+			parse_indent(p, &_indent, false);
+			if (_indent < *indent) {
+				parser_fatal(p, "Cannot deindent in literal block");
+			}
+			while (_indent > *indent) {
+				--_indent;
+				fprintf(p->output, "\t");
+			}
+			check_indent = false;
 		}
 		if ((ch = parser_getch(p)) == UTF8_INVALID) {
 			break;
@@ -421,6 +419,9 @@ static void parse_literal(struct parser *p, int *indent) {
 					utf8_fputch(p->output, ch);
 				}
 				break;
+			case '\n':
+				check_indent = true;
+				/* fallthrough */
 			default:
 				utf8_fputch(p->output, ch);
 				break;
@@ -433,6 +434,9 @@ enum table_align {
 	ALIGN_LEFT,
 	ALIGN_CENTER,
 	ALIGN_RIGHT,
+	ALIGN_LEFT_EXPAND,
+	ALIGN_CENTER_EXPAND,
+	ALIGN_RIGHT_EXPAND,
 };
 
 struct table_row {
@@ -507,6 +511,15 @@ static void parse_table(struct parser *p, uint32_t style) {
 		case ']':
 			curcell->align = ALIGN_RIGHT;
 			break;
+		case '<':
+			curcell->align = ALIGN_LEFT_EXPAND;
+			break;
+		case '=':
+			curcell->align = ALIGN_CENTER_EXPAND;
+			break;
+		case '>':
+			curcell->align = ALIGN_RIGHT_EXPAND;
+			break;
 		case ' ':
 			if (prevrow) {
 				struct table_cell *pcell = prevrow->cell;
@@ -575,8 +588,28 @@ commit_table:
 	while (currow) {
 		curcell = currow->cell;
 		while (curcell) {
-			fprintf(p->output, "%c%s", "lcr"[curcell->align],
-					curcell->next ? " " : "");
+			char *align = "";
+			switch (curcell->align) {
+			case ALIGN_LEFT:
+				align = "l";
+				break;
+			case ALIGN_CENTER:
+				align = "c";
+				break;
+			case ALIGN_RIGHT:
+				align = "r";
+				break;
+			case ALIGN_LEFT_EXPAND:
+				align = "lx";
+				break;
+			case ALIGN_CENTER_EXPAND:
+				align = "cx";
+				break;
+			case ALIGN_RIGHT_EXPAND:
+				align = "rx";
+				break;
+			}
+			fprintf(p->output, "%s%s", align, curcell->next ? " " : "");
 			curcell = curcell->next;
 		}
 		fprintf(p->output, "%s\n", currow->next ? "" : ".");
